@@ -1,8 +1,11 @@
 from __future__ import annotations
 
+import asyncio
 import re
+from functools import partial
 from pathlib import Path, PurePath
 from typing import Callable, Iterable, Optional
+from urllib.parse import unquote
 
 from markdown_it import MarkdownIt
 from markdown_it.token import Token
@@ -13,15 +16,15 @@ from rich.table import Table
 from rich.text import Text
 from typing_extensions import TypeAlias
 
-from .._slug import TrackedSlugs
-from ..app import ComposeResult
-from ..await_complete import AwaitComplete
-from ..containers import Horizontal, Vertical, VerticalScroll
-from ..events import Mount
-from ..message import Message
-from ..reactive import reactive, var
-from ..widget import Widget
-from ..widgets import Static, Tree
+from textual._slug import TrackedSlugs
+from textual.app import ComposeResult
+from textual.await_complete import AwaitComplete
+from textual.containers import Horizontal, Vertical, VerticalScroll
+from textual.events import Mount
+from textual.message import Message
+from textual.reactive import reactive, var
+from textual.widget import Widget
+from textual.widgets import Static, Tree
 
 TableOfContentsType: TypeAlias = "list[tuple[int, str, str | None]]"
 """Information about the table of contents of a markdown document.
@@ -48,6 +51,16 @@ class Navigator:
             return Path(".")
         return self.stack[self.index]
 
+    @property
+    def start(self) -> bool:
+        """Is the current location at the start of the stack?"""
+        return self.index == 0
+
+    @property
+    def end(self) -> bool:
+        """Is the current location at the end of the stack?"""
+        return self.index >= len(self.stack) - 1
+
     def go(self, path: str | PurePath) -> Path:
         """Go to a new document.
 
@@ -108,6 +121,10 @@ class MarkdownBlock(Static):
         self._blocks: list[MarkdownBlock] = []
         super().__init__(*args, **kwargs)
 
+    @property
+    def select_container(self) -> Widget:
+        return self.query_ancestor(Markdown)
+
     def compose(self) -> ComposeResult:
         yield from self._blocks
         self._blocks.clear()
@@ -221,6 +238,8 @@ class MarkdownHeader(MarkdownBlock):
     DEFAULT_CSS = """
     MarkdownHeader {
         color: $text;
+        margin: 2 0 1 0;
+
     }
     """
 
@@ -229,15 +248,11 @@ class MarkdownH1(MarkdownHeader):
     """An H1 Markdown header."""
 
     DEFAULT_CSS = """
-
     MarkdownH1 {
-        background: $accent-darken-2;
-        border: wide $background;
         content-align: center middle;
-
-        padding: 1;
-        text-style: bold;
-        color: $text;
+        color: $markdown-h1-color;
+        background: $markdown-h1-background;
+        text-style: $markdown-h1-text-style;
     }
     """
 
@@ -246,15 +261,10 @@ class MarkdownH2(MarkdownHeader):
     """An H2 Markdown header."""
 
     DEFAULT_CSS = """
-
     MarkdownH2 {
-        background: $panel;
-        border: wide $background;
-        text-align: center;
-        text-style: underline;
-        color: $text;
-        padding: 1;
-        text-style: bold;
+        color: $markdown-h2-color;
+        background: $markdown-h2-background;
+        text-style: $markdown-h2-text-style;
     }
     """
 
@@ -264,10 +274,10 @@ class MarkdownH3(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH3 {
-        background: $surface;
-        text-style: bold;
-        color: $text;
-        border-bottom: wide $foreground;
+        color: $markdown-h3-color;
+        background: $markdown-h3-background;
+        text-style: $markdown-h3-text-style;
+        margin: 1 0;
         width: auto;
     }
     """
@@ -278,7 +288,9 @@ class MarkdownH4(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH4 {
-        text-style: underline;
+        color: $markdown-h4-color;
+        background: $markdown-h4-background;
+        text-style: $markdown-h4-text-style;
         margin: 1 0;
     }
     """
@@ -289,8 +301,9 @@ class MarkdownH5(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH5 {
-        text-style: bold;
-        color: $text;
+        color: $markdown-h5-color;
+        background: $markdown-h5-background;
+        text-style: $markdown-h5-text-style;
         margin: 1 0;
     }
     """
@@ -301,8 +314,9 @@ class MarkdownH6(MarkdownHeader):
 
     DEFAULT_CSS = """
     MarkdownH6 {
-        text-style: bold;
-        color: $text-muted;
+        color: $markdown-h6-color;
+        background: $markdown-h6-background;
+        text-style: $markdown-h6-text-style;
         margin: 1 0;
     }
     """
@@ -313,7 +327,7 @@ class MarkdownHorizontalRule(MarkdownBlock):
 
     DEFAULT_CSS = """
     MarkdownHorizontalRule {
-        border-bottom: heavy $primary;
+        border-bottom: heavy $secondary;
         height: 1;
         padding-top: 1;
         margin-bottom: 1;
@@ -338,10 +352,13 @@ class MarkdownBlockQuote(MarkdownBlock):
     DEFAULT_CSS = """
     MarkdownBlockQuote {
         background: $boost;
-        border-left: outer $success;
+        border-left: outer $primary 50%;
         margin: 1 0;
         padding: 0 1;
     }
+    MarkdownBlockQuote:light {
+        border-left: outer $secondary;
+    }
     MarkdownBlockQuote > BlockQuote {
         margin-left: 2;
         margin-top: 1;
@@ -408,7 +425,7 @@ class MarkdownOrderedList(MarkdownList):
 
     MarkdownOrderedList Vertical {
         height: auto;
-        width: 1fr;
+        width: 1fr;        
     }
     """
 
@@ -461,7 +478,7 @@ class MarkdownTableContent(Widget):
     def render(self) -> Table:
         table = Table(
             expand=True,
-            box=box.SIMPLE_HEAVY,
+            box=box.SIMPLE_HEAD,
             style=self.rich_style,
             header_style=self.get_component_rich_style("markdown-table--header"),
             border_style=self.get_component_rich_style("markdown-table--lines"),
@@ -475,6 +492,11 @@ class MarkdownTableContent(Widget):
                 table.add_row(*row)
         return table
 
+    async def action_link(self, href: str) -> None:
+        """Pass a link action on to the MarkdownTable parent."""
+        if isinstance(self.parent, MarkdownTable):
+            await self.parent.action_link(href)
+
 
 class MarkdownTable(MarkdownBlock):
     """A Table markdown Block."""
@@ -482,9 +504,10 @@ class MarkdownTable(MarkdownBlock):
     DEFAULT_CSS = """
     MarkdownTable {
         width: 100%;
-        margin: 1 0;
-        background: $panel;
-        border: wide $background;
+        background: black 10%;
+        &:light {
+            background: white 30%;
+        }
     }
     """
 
@@ -535,14 +558,20 @@ class MarkdownBullet(Widget):
     DEFAULT_CSS = """
     MarkdownBullet {
         width: auto;
-        color: $success;
+        color: $text;
         text-style: bold;
+        &:light {
+            color: $secondary;
+        }
     }
     """
 
-    symbol = reactive("\u25CF")
+    symbol = reactive("\u25cf")
     """The symbol for the bullet."""
 
+    def get_selection(self, _selection) -> tuple[str, str] | None:
+        return self.symbol, " "
+
     def render(self) -> Text:
         return Text(self.symbol)
 
@@ -587,6 +616,11 @@ class MarkdownFence(MarkdownBlock):
         height: auto;
         max-height: 20;
         color: rgb(210,210,210);
+        background: black 10%;
+
+        &:light {
+            background: white 30%;
+        }
     }
 
     MarkdownFence > * {
@@ -600,29 +634,34 @@ class MarkdownFence(MarkdownBlock):
         self.lexer = lexer
         self.theme = (
             self._markdown.code_dark_theme
-            if self.app.dark
+            if self.app.current_theme.dark
             else self._markdown.code_light_theme
         )
 
+    def notify_style_update(self) -> None:
+        self.call_later(self._retheme)
+
     def _block(self) -> Syntax:
+        _, background_color = self.background_colors
         return Syntax(
             self.code,
             lexer=self.lexer,
             word_wrap=False,
-            indent_guides=True,
+            indent_guides=self._markdown.code_indent_guides,
             padding=(1, 2),
             theme=self.theme,
+            background_color=background_color.css,
         )
 
     def _on_mount(self, _: Mount) -> None:
         """Watch app theme switching."""
-        self.watch(self.app, "dark", self._retheme)
+        self.watch(self.app, "theme", self._retheme)
 
     def _retheme(self) -> None:
         """Rerender when the theme changes."""
         self.theme = (
             self._markdown.code_dark_theme
-            if self.app.dark
+            if self.app.current_theme.dark
             else self._markdown.code_light_theme
         )
         self.get_child_by_type(Static).update(self._block())
@@ -651,8 +690,15 @@ class Markdown(Widget):
     DEFAULT_CSS = """
     Markdown {
         height: auto;
-        margin: 0 4 1 4;
+        padding: 0 2 1 2;
         layout: vertical;
+        color: $foreground;
+        background: $surface;
+        overflow-y: auto;
+
+        &:focus {
+            background-tint: $foreground 5%;
+        }
     }
     .em {
         text-style: italic;
@@ -677,17 +723,20 @@ class Markdown(Widget):
     | :- | :- |
     | `code_inline` | Target text that is styled as inline code. |
     | `em` | Target text that is emphasized inline. |
-    | `s` | Target text that is styled inline with strykethrough. |
+    | `s` | Target text that is styled inline with strikethrough. |
     | `strong` | Target text that is styled inline with strong. |
     """
 
-    BULLETS = ["\u25CF ", "▪ ", "‣ ", "• ", "⭑ "]
+    BULLETS = ["\u25cf ", "▪ ", "‣ ", "• ", "⭑ "]
 
     code_dark_theme: reactive[str] = reactive("material")
-    """The theme to use for code blocks when in [dark mode][textual.app.App.dark]."""
+    """The theme to use for code blocks when the App theme is dark."""
 
     code_light_theme: reactive[str] = reactive("material-light")
-    """The theme to use for code blocks when in [light mode][textual.app.App.dark]."""
+    """The theme to use for code blocks when the App theme is light."""
+
+    code_indent_guides: reactive[bool] = reactive(True)
+    """Should code fences display indent guides?"""
 
     def __init__(
         self,
@@ -697,6 +746,7 @@ class Markdown(Widget):
         id: str | None = None,
         classes: str | None = None,
         parser_factory: Callable[[], MarkdownIt] | None = None,
+        open_links: bool = True,
     ):
         """A Markdown widget.
 
@@ -706,11 +756,13 @@ class Markdown(Widget):
             id: The ID of the widget in the DOM.
             classes: The CSS classes of the widget.
             parser_factory: A factory function to return a configured MarkdownIt instance. If `None`, a "gfm-like" parser is used.
+            open_links: Open links automatically. If you set this to `False`, you can handle the [`LinkClicked`][textual.widgets.markdown.Markdown.LinkClicked] events.
         """
         super().__init__(name=name, id=id, classes=classes)
         self._markdown = markdown
         self._parser_factory = parser_factory
         self._table_of_contents: TableOfContentsType | None = None
+        self._open_links = open_links
 
     class TableOfContentsUpdated(Message):
         """The table of contents was updated."""
@@ -759,7 +811,7 @@ class Markdown(Widget):
             super().__init__()
             self.markdown: Markdown = markdown
             """The `Markdown` widget containing the link clicked."""
-            self.href: str = href
+            self.href: str = unquote(href)
             """The link that was selected."""
 
         @property
@@ -771,19 +823,23 @@ class Markdown(Widget):
             """
             return self.markdown
 
-    def _on_mount(self, _: Mount) -> None:
+    async def _on_mount(self, _: Mount) -> None:
         if self._markdown is not None:
-            self.update(self._markdown)
+            await self.update(self._markdown)
+
+    def on_markdown_link_clicked(self, event: LinkClicked) -> None:
+        if self._open_links:
+            self.app.open_url(event.href)
 
     def _watch_code_dark_theme(self) -> None:
         """React to the dark theme being changed."""
-        if self.app.dark:
+        if self.app.current_theme.dark:
             for block in self.query(MarkdownFence):
                 block._retheme()
 
     def _watch_code_light_theme(self) -> None:
         """React to the light theme being changed."""
-        if not self.app.dark:
+        if not self.app.current_theme.dark:
             for block in self.query(MarkdownFence):
                 block._retheme()
 
@@ -823,7 +879,7 @@ class Markdown(Widget):
         unique = TrackedSlugs()
         for _, title, header_id in self._table_of_contents:
             if unique.slug(title) == anchor:
-                self.parent.scroll_to_widget(self.query_one(f"#{header_id}"), top=True)
+                self.query_one(f"#{header_id}").scroll_visible(top=True)
                 return True
         return False
 
@@ -841,7 +897,10 @@ class Markdown(Widget):
             those that can be raised by calling [`Path.read_text`][pathlib.Path.read_text].
         """
         path, anchor = self.sanitize_location(str(path))
-        await self.update(path.read_text(encoding="utf-8"))
+        data = await asyncio.get_running_loop().run_in_executor(
+            None, partial(path.read_text, encoding="utf-8")
+        )
+        await self.update(data)
         if anchor:
             self.goto_anchor(anchor)
 
@@ -865,93 +924,143 @@ class Markdown(Widget):
         Returns:
             An optionally awaitable object. Await this to ensure that all children have been mounted.
         """
-        output: list[MarkdownBlock] = []
-        stack: list[MarkdownBlock] = []
         parser = (
             MarkdownIt("gfm-like")
             if self._parser_factory is None
             else self._parser_factory()
         )
 
-        block_id: int = 0
-        self._table_of_contents = []
+        table_of_contents = []
 
-        for token in parser.parse(markdown):
-            if token.type == "heading_open":
-                block_id += 1
-                stack.append(HEADINGS[token.tag](self, id=f"block{block_id}"))
-            elif token.type == "hr":
-                output.append(MarkdownHorizontalRule(self))
-            elif token.type == "paragraph_open":
-                stack.append(MarkdownParagraph(self))
-            elif token.type == "blockquote_open":
-                stack.append(MarkdownBlockQuote(self))
-            elif token.type == "bullet_list_open":
-                stack.append(MarkdownBulletList(self))
-            elif token.type == "ordered_list_open":
-                stack.append(MarkdownOrderedList(self))
-            elif token.type == "list_item_open":
-                if token.info:
-                    stack.append(MarkdownOrderedListItem(self, token.info))
-                else:
-                    item_count = sum(
-                        1
-                        for block in stack
-                        if isinstance(block, MarkdownUnorderedListItem)
-                    )
-                    stack.append(
-                        MarkdownUnorderedListItem(
-                            self,
-                            self.BULLETS[item_count % len(self.BULLETS)],
+        def parse_markdown(tokens) -> Iterable[MarkdownBlock]:
+            """Create a stream of MarkdownBlock widgets from markdown.
+
+            Args:
+                tokens: List of tokens
+
+            Yields:
+                Widgets for mounting.
+            """
+
+            stack: list[MarkdownBlock] = []
+            stack_append = stack.append
+            block_id: int = 0
+
+            for token in tokens:
+                token_type = token.type
+                if token_type == "heading_open":
+                    block_id += 1
+                    stack_append(HEADINGS[token.tag](self, id=f"block{block_id}"))
+                elif token_type == "hr":
+                    yield MarkdownHorizontalRule(self)
+                elif token_type == "paragraph_open":
+                    stack_append(MarkdownParagraph(self))
+                elif token_type == "blockquote_open":
+                    stack_append(MarkdownBlockQuote(self))
+                elif token_type == "bullet_list_open":
+                    stack_append(MarkdownBulletList(self))
+                elif token_type == "ordered_list_open":
+                    stack_append(MarkdownOrderedList(self))
+                elif token_type == "list_item_open":
+                    if token.info:
+                        stack_append(MarkdownOrderedListItem(self, token.info))
+                    else:
+                        item_count = sum(
+                            1
+                            for block in stack
+                            if isinstance(block, MarkdownUnorderedListItem)
                         )
-                    )
-
-            elif token.type == "table_open":
-                stack.append(MarkdownTable(self))
-            elif token.type == "tbody_open":
-                stack.append(MarkdownTBody(self))
-            elif token.type == "thead_open":
-                stack.append(MarkdownTHead(self))
-            elif token.type == "tr_open":
-                stack.append(MarkdownTR(self))
-            elif token.type == "th_open":
-                stack.append(MarkdownTH(self))
-            elif token.type == "td_open":
-                stack.append(MarkdownTD(self))
-            elif token.type.endswith("_close"):
-                block = stack.pop()
-                if token.type == "heading_close":
-                    heading = block._text.plain
-                    level = int(token.tag[1:])
-                    self._table_of_contents.append((level, heading, block.id))
-                if stack:
-                    stack[-1]._blocks.append(block)
+                        stack_append(
+                            MarkdownUnorderedListItem(
+                                self,
+                                self.BULLETS[item_count % len(self.BULLETS)],
+                            )
+                        )
+                elif token_type == "table_open":
+                    stack_append(MarkdownTable(self))
+                elif token_type == "tbody_open":
+                    stack_append(MarkdownTBody(self))
+                elif token_type == "thead_open":
+                    stack_append(MarkdownTHead(self))
+                elif token_type == "tr_open":
+                    stack_append(MarkdownTR(self))
+                elif token_type == "th_open":
+                    stack_append(MarkdownTH(self))
+                elif token_type == "td_open":
+                    stack_append(MarkdownTD(self))
+                elif token_type.endswith("_close"):
+                    block = stack.pop()
+                    if token.type == "heading_close":
+                        heading = block._text.plain
+                        level = int(token.tag[1:])
+                        table_of_contents.append((level, heading, block.id))
+                    if stack:
+                        stack[-1]._blocks.append(block)
+                    else:
+                        yield block
+                elif token_type == "inline":
+                    stack[-1].build_from_token(token)
+                elif token_type in ("fence", "code_block"):
+                    fence = MarkdownFence(self, token.content.rstrip(), token.info)
+                    if stack:
+                        stack[-1]._blocks.append(fence)
+                    else:
+                        yield fence
                 else:
-                    output.append(block)
-            elif token.type == "inline":
-                stack[-1].build_from_token(token)
-            elif token.type in ("fence", "code_block"):
-                (stack[-1]._blocks if stack else output).append(
-                    MarkdownFence(self, token.content.rstrip(), token.info)
-                )
-            else:
-                external = self.unhandled_token(token)
-                if external is not None:
-                    (stack[-1]._blocks if stack else output).append(external)
+                    external = self.unhandled_token(token)
+                    if external is not None:
+                        if stack:
+                            stack[-1]._blocks.append(external)
+                        else:
+                            yield external
 
-        self.post_message(
-            Markdown.TableOfContentsUpdated(self, self._table_of_contents).set_sender(
-                self
-            )
-        )
         markdown_block = self.query("MarkdownBlock")
 
         async def await_update() -> None:
-            """Update in a single batch."""
+            """Update in batches."""
+            BATCH_SIZE = 200
+            batch: list[MarkdownBlock] = []
+            tokens = await asyncio.get_running_loop().run_in_executor(
+                None, parser.parse, markdown
+            )
 
-            with self.app.batch_update():
-                await markdown_block.remove()
-                await self.mount_all(output)
+            # Lock so that you can't update with more than one document simultaneously
+            async with self.lock:
+                # Remove existing blocks for the first batch only
+                removed: bool = False
+
+                async def mount_batch(batch: list[MarkdownBlock]) -> None:
+                    """Mount a single match of blocks.
+
+                    Args:
+                        batch: A list of blocks to mount.
+                    """
+                    nonlocal removed
+                    if removed:
+                        await self.mount_all(batch)
+                    else:
+                        with self.app.batch_update():
+                            await markdown_block.remove()
+                            await self.mount_all(batch)
+                        removed = True
+
+                for block in parse_markdown(tokens):
+                    batch.append(block)
+                    if len(batch) == BATCH_SIZE:
+                        await mount_batch(batch)
+                        batch.clear()
+                if batch:
+                    await mount_batch(batch)
+                if not removed:
+                    await markdown_block.remove()
+
+            self._table_of_contents = table_of_contents
+
+            self.post_message(
+                Markdown.TableOfContentsUpdated(
+                    self, self._table_of_contents
+                ).set_sender(self)
+            )
 
         return AwaitComplete(await_update())
 
@@ -962,12 +1071,17 @@ class MarkdownTableOfContents(Widget, can_focus_children=True):
     DEFAULT_CSS = """
     MarkdownTableOfContents {
         width: auto;
+        height: 1fr;
         background: $panel;
-        border-right: wide $background;
+        &:focus-within {
+            background-tint: $foreground 5%;
+        }
     }
     MarkdownTableOfContents > Tree {
         padding: 1;
         width: auto;
+        height: 1fr;
+        background: $panel;
     }
     """
 
@@ -1037,7 +1151,7 @@ class MarkdownTableOfContents(Widget, can_focus_children=True):
         message.stop()
 
 
-class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
+class MarkdownViewer(VerticalScroll, can_focus=False, can_focus_children=True):
     """A Markdown viewer widget."""
 
     SCOPED_CSS = False
@@ -1046,14 +1160,11 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
     MarkdownViewer {
         height: 1fr;
         scrollbar-gutter: stable;
-    }
-
-    MarkdownTableOfContents {
-        dock:left;
-    }
-
-    MarkdownViewer > MarkdownTableOfContents {
-        display: none;
+        background: $surface;
+        & > MarkdownTableOfContents {
+            display: none;
+            dock:left;
+        }
     }
 
     MarkdownViewer.-show-table-of-contents > MarkdownTableOfContents {
@@ -1062,10 +1173,16 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
     """
 
     show_table_of_contents = reactive(True)
+    """Show the table of contents?"""
+    code_indent_guides: reactive[bool] = reactive(True)
+    """Should code fences display indent guides?"""
     top_block = reactive("")
 
     navigator: var[Navigator] = var(Navigator)
 
+    class NavigatorUpdated(Message):
+        """Navigator has been changed (clicked link etc)."""
+
     def __init__(
         self,
         markdown: str | None = None,
@@ -1075,6 +1192,7 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         id: str | None = None,
         classes: str | None = None,
         parser_factory: Callable[[], MarkdownIt] | None = None,
+        open_links: bool = True,
     ):
         """Create a Markdown Viewer object.
 
@@ -1085,11 +1203,13 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
             id: The ID of the widget in the DOM.
             classes: The CSS classes of the widget.
             parser_factory: A factory function to return a configured MarkdownIt instance. If `None`, a "gfm-like" parser is used.
+            open_links: Open links automatically. If you set this to `False`, you can handle the [`LinkClicked`][textual.widgets.markdown.Markdown.LinkClicked] events.
         """
         super().__init__(name=name, id=id, classes=classes)
         self.show_table_of_contents = show_table_of_contents
         self._markdown = markdown
         self._parser_factory = parser_factory
+        self._open_links = open_links
 
     @property
     def document(self) -> Markdown:
@@ -1101,9 +1221,9 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         """The [table of contents][textual.widgets.markdown.MarkdownTableOfContents] widget."""
         return self.query_one(MarkdownTableOfContents)
 
-    def _on_mount(self, _: Mount) -> None:
+    async def _on_mount(self, _: Mount) -> None:
         if self._markdown is not None:
-            self.document.update(self._markdown)
+            await self.document.update(self._markdown)
 
     async def go(self, location: str | PurePath) -> None:
         """Navigate to a new document path."""
@@ -1114,16 +1234,19 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         else:
             # We've been asked to go to a file, optionally with an anchor.
             await self.document.load(self.navigator.go(location))
+            self.post_message(self.NavigatorUpdated())
 
     async def back(self) -> None:
         """Go back one level in the history."""
         if self.navigator.back():
             await self.document.load(self.navigator.location)
+            self.post_message(self.NavigatorUpdated())
 
     async def forward(self) -> None:
         """Go forward one level in the history."""
         if self.navigator.forward():
             await self.document.load(self.navigator.location)
+            self.post_message(self.NavigatorUpdated())
 
     async def _on_markdown_link_clicked(self, message: Markdown.LinkClicked) -> None:
         message.stop()
@@ -1133,9 +1256,12 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         self.set_class(show_table_of_contents, "-show-table-of-contents")
 
     def compose(self) -> ComposeResult:
-        markdown = Markdown(parser_factory=self._parser_factory)
+        markdown = Markdown(
+            parser_factory=self._parser_factory, open_links=self._open_links
+        )
+        markdown.can_focus = True
+        yield markdown.data_bind(MarkdownViewer.code_indent_guides)
         yield MarkdownTableOfContents(markdown)
-        yield markdown
 
     def _on_markdown_table_of_contents_updated(
         self, message: Markdown.TableOfContentsUpdated
